@@ -43,7 +43,7 @@ using namespace std;
 namespace gcu
 {
 
-/*!\enum TypeId
+/*!\enum GcuTypeId
 This enumeration is used to determine the type of an Object instance.
 Possible values are:
 	- NoType: invalid type
@@ -67,7 +67,7 @@ Possible values are:
 Some types are not used in  the Gnome Chemistry Utils, but only in GChemPaint
 and might disappear from this list in future versions and replaced by dynamically created types.
 */	
-enum
+enum GcuTypeId
 {
 	NoType,
 	AtomType,
@@ -87,6 +87,10 @@ enum
 	OtherType
 };
 
+/*!
+The type of an object instance. Either predefined types are defined in the enum above
+or dynamically defined types by calls to Object::AddType.
+*/
 typedef unsigned TypeId;
 
 /*!\enum RuleId
@@ -109,6 +113,10 @@ enum RuleId
 	RuleMustBeIn
 };
 
+/*!
+The types of the signals used in Object::EmitSignal() and Object::OnSignal(). Each signal
+must type be retrieved from a call to Object::CreateNewSignalId().
+*/
 typedef unsigned SignalId;
 
 class Document;
@@ -395,6 +403,8 @@ every derived class for which alignment has a meaning should implement this meth
 /*!
 @param UIManager: the GtkUI%anager to populate.
 @param object: the Object on which occured the mouse click.
+@param x: x coordinate of the mouse click.
+@param y: y coordinate of the mouse click.
 
 This method is called to build a contextual menu for the object. It is called by Object::ShowContextualMenu, so
 it should not be necessary to call it directly. It should be overrided by derived classes when a contextual menu
@@ -402,7 +412,7 @@ is needed. Typically, each class adds a submenu and calls the same method for it
 Default implementation just calls the parent's method.
 @return true if something is added to the UIManager, false otherwise.
 */
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
 
 /*!
 @param Signal: the appropriate SignalId
