@@ -23,9 +23,6 @@
  */
 
 #include "config.h"
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchemutils-unstable" 
 #include <gcu/application.h>
 #include <gcu/element.h>
 #include <gcu/formula.h>
@@ -62,7 +59,7 @@
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <math.h>
+#include <cmath>
 #include <iostream>
 
 using namespace gcu;
@@ -83,7 +80,7 @@ public:
 	GtkListStore *pclist;
 };
 
-GChemCalc::GChemCalc (): Application ("gchemcalc-unstable"),
+GChemCalc::GChemCalc (): Application ("gchemcalc"),
 formula ("")
 {
 }
@@ -128,7 +125,7 @@ static void on_about (GtkWidget *widget, void *data)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemCalc is a simple calculator for chemists");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = "Copyright \xc2\xa9 2005,2006 Jean Bréfort\n";
+	const gchar * copyright = _("Copyright © 2005-2007 Jean Bréfort\n");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -501,9 +498,8 @@ int main (int argc, char *argv[])
 		argv ++;
 	}
 
-#warning "the following line should be edited for stable releases"
 	if (argc > 1) {
-		cout << _("For usage see: gchemcalc-unstable [-?|--help]") << endl;
+		cout << _("For usage see: gchemcalc [-?|--help]") << endl;
 		return -1;
 	}
 	
@@ -604,7 +600,7 @@ int main (int argc, char *argv[])
 	g_signal_connect (GTK_OBJECT (w), "activate",
 		 G_CALLBACK (cb_entry_active),
 		 window);
-	gcu_element_load_databases ("isotopes", NULL);
+	gcu_element_load_databases ((char*) "isotopes", NULL);
 	if (argc == 1){
 		gtk_entry_set_text (GTK_ENTRY (w), argv[0]);
 		cb_entry_active (GTK_ENTRY (w), window);
