@@ -4,7 +4,7 @@
  * Gnome Crystal
  * view.cc 
  *
- * Copyright (C) 2000-2005 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,12 +26,12 @@
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include <gtk/gtkgl.h>
-#include <math.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
 #include "view.h"
 #include "document.h"
 #include "globals.h"
+#include <cmath>
 
 guint FoV;
 gdouble Psi, Theta, Phi;
@@ -46,11 +46,12 @@ gcView::gcView (gcDocument *pDoc): CrystalView (pDoc)
 	SetRed (Red);
 	SetGreen (Green);
 	SetAlpha (1.0);
-	m_pLabel = NULL;
 	m_Window = NULL;
 }
 
-gcView::gcView (gcView *pView): CrystalView (dynamic_cast <CrystalDoc *> (pView->GetDoc ()))
+gcView::gcView (gcView *pView):
+	CrystalView (dynamic_cast <CrystalDoc *> (pView->GetDoc ())),
+	DialogOwner ()
 {
 	SetAngle (pView->GetAngle ());
 	SetRotation (pView->GetPsi (), pView->GetTheta (), pView->GetPhi ());
@@ -59,8 +60,6 @@ gcView::gcView (gcView *pView): CrystalView (dynamic_cast <CrystalDoc *> (pView-
 	SetGreen (pView->GetGreen ());
 	SetAlpha (pView->GetAlpha ());
 	dynamic_cast <gcDocument*> (GetDoc())->AddView (this);
-	m_pLabel = NULL;
-	m_Window = NULL;
 }
 
 gcView::~gcView ()
@@ -140,26 +139,3 @@ bool gcView::LoadOld(xmlNodePtr node)
 	}
 	return true;
 }
-
-void gcView::SetMenu(GtkMenuItem* item)
-{
-	m_pMenu = item;
-	m_pMenuLabel = NULL;
-	GList* l;
-	for (l = gtk_container_get_children(GTK_CONTAINER(item)); l != NULL; l = g_list_next(l))
-		if (GTK_IS_LABEL(l->data))
-		{
-			m_pMenuLabel = (GtkLabel*)(l->data);
-			break;
-		}
-}
-
-void gcView::NotifyDialog (Dialog* dialog)
-{
-	m_Dialogs.push_front (dialog);
-}
-
-void gcView::RemoveDialog (Dialog* dialog)
-{
-	m_Dialogs.remove (dialog);
-}
